@@ -1,12 +1,12 @@
 package Test::BDD::Cucumber::Extension;
-$Test::BDD::Cucumber::Extension::VERSION = '0.44';
+$Test::BDD::Cucumber::Extension::VERSION = '0.45';
 =head1 NAME
 
 Test::BDD::Cucumber::Extension - Abstract superclass for extensions
 
 =head1 VERSION
 
-version 0.44
+version 0.45
 
 =head1 DESCRIPTION
 
@@ -17,7 +17,6 @@ the BDD script execution.
 =cut
 
 use Moose;
-use namespace::autoclean;
 
 =head1 PROPERTIES
 
@@ -82,7 +81,7 @@ Invoked by the Executor before executing each step in $scenario.
 Reports errors by calling croak().
 
 Feature and scenario stashes can be reached through
- $step_context->{stash}->{feature} and 
+ $step_context->{stash}->{feature} and
  $step_context->{stash}->{scenario}
 
 Note: *executed* steps, so not called for skipped steps.
@@ -111,6 +110,4 @@ Copyright 2016, Erik Huelsmann; Licensed under the same terms as Perl
 
 =cut
 
-__PACKAGE__->meta->make_immutable;
-
 1;
